@@ -1,18 +1,13 @@
-from typing import Optional
-
-import requests
-
-from ..repositories.settings import SettingsRepository
-
+from galileo_sdk.compat import requests
 
 class AuthProvider:
     def __init__(
         self,
-        settings_repository: SettingsRepository,
-        auth_token: Optional[str] = None,
-        refresh_token: Optional[str] = None,
-        username: Optional[str] = None,
-        password: Optional[str] = None,
+        settings_repository,
+        auth_token=None,
+        refresh_token=None,
+        username=None,
+        password=None,
     ):
         self._settings_repository = settings_repository
         settings = self._settings_repository.get_settings()
@@ -22,7 +17,9 @@ class AuthProvider:
             self._refresh_token = refresh_token
         elif username and password:
             r = requests.post(
-                f"{settings.backend}/galileo/landing_zone/v1/oauth/token",
+                "{backend}/galileo/landing_zone/v1/oauth/token".format(
+                    backend=settings.backend
+                ),
                 json={
                     "username": username,
                     "password": password,
@@ -42,3 +39,6 @@ class AuthProvider:
 
     def get_refresh_token(self):
         return self._refresh_token
+
+    def set_access_token(self, auth_token):
+        self._access_token = auth_token
